@@ -1,10 +1,10 @@
 package Net::DNS::RR::NSEC3;
 
 #
-# $Id: NSEC3.pm 1193 2014-04-28 07:11:19Z willem $
+# $Id: NSEC3.pm 1236 2014-07-29 08:00:49Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1193 $)[1];
+$VERSION = (qw$LastChangedRevision: 1236 $)[1];
 
 
 use strict;
@@ -18,6 +18,7 @@ Net::DNS::RR::NSEC3 - DNS NSEC3 resource record
 
 
 use integer;
+
 use warnings;
 use Carp;
 use MIME::Base32;
@@ -108,7 +109,8 @@ sub parse_rdata {			## populate RR from rdata in argument list
 	$self->algorithm(shift);
 	$self->flags(shift);
 	$self->iterations(shift);
-	$self->salt(shift);
+	my $salt = shift;
+	$self->salt( defined($salt) && ( $salt ne '-' ) ? $salt : '' );
 	$self->hnxtname(shift);
 	$self->typelist(@_);
 }
